@@ -1,4 +1,4 @@
-from cassarrow.impl import install_cassarrow, result_set_to_table, metadata_to_schema
+from cassarrow.impl import install_cassarrow, metadata_to_schema, result_set_to_table
 
 __version__ = "0.1.0"
 
